@@ -9,17 +9,21 @@ use Test::More;
 
 use Yahoo::Marketing::BulkDownloadStatusResponse;
 
-sub test_can_create_bulk_download_status_response_and_set_all_fields : Test(3) {
+sub test_can_create_bulk_download_status_response_and_set_all_fields : Test(5) {
 
     my $bulk_download_status_response = Yahoo::Marketing::BulkDownloadStatusResponse->new
                                                                                     ->downloadUrl( 'download url' )
+                                                                                    ->locale( 'locale' )
                                                                                     ->status( 'status' )
+                                                                                    ->timeRemaining( 'time remaining' )
                    ;
 
     ok( $bulk_download_status_response );
 
     is( $bulk_download_status_response->downloadUrl, 'download url', 'can get download url' );
+    is( $bulk_download_status_response->locale, 'locale', 'can get locale' );
     is( $bulk_download_status_response->status, 'status', 'can get status' );
+    is( $bulk_download_status_response->timeRemaining, 'time remaining', 'can get time remaining' );
 
 };
 
